@@ -18,10 +18,9 @@ class test_object_properties(unittest.TestCase):
             name="test_material",
             materials=[
                 nmm.Material.from_library("Li4SiO4"),
-                nmm.Material.from_library("Be12Ti")],
-            fracs=[
-                0.50,
-                0.50],
+                nmm.Material.from_library("Be12Ti"),
+            ],
+            fracs=[0.50, 0.50],
             percent_type="vo",
         )
 
@@ -34,10 +33,9 @@ class test_object_properties(unittest.TestCase):
             name="test_material",
             materials=[
                 nmm.Material.from_library("Li4SiO4"),
-                nmm.Material.from_library("Be12Ti")],
-            fracs=[
-                0.50,
-                0.50],
+                nmm.Material.from_library("Be12Ti"),
+            ],
+            fracs=[0.50, 0.50],
             percent_type="vo",
             material_id=2,
         )
@@ -51,10 +49,9 @@ class test_object_properties(unittest.TestCase):
             name="test_material",
             materials=[
                 nmm.Material.from_library("Li4SiO4"),
-                nmm.Material.from_library("Be12Ti")],
-            fracs=[
-                0.50,
-                0.50],
+                nmm.Material.from_library("Be12Ti"),
+            ],
+            fracs=[0.50, 0.50],
             percent_type="vo",
             temperature=300,
             material_id=2,
@@ -69,10 +66,9 @@ class test_object_properties(unittest.TestCase):
             name="test_material",
             materials=[
                 nmm.Material.from_library("Li4SiO4"),
-                nmm.Material.from_library("Be12Ti")],
-            fracs=[
-                0.50,
-                0.50],
+                nmm.Material.from_library("Be12Ti"),
+            ],
+            fracs=[0.50, 0.50],
             percent_type="vo",
             volume_in_cm3=20,
         )
@@ -88,10 +84,9 @@ class test_object_properties(unittest.TestCase):
             name="test_material",
             materials=[
                 nmm.Material.from_library("Li4SiO4"),
-                nmm.Material.from_library("Be12Ti")],
-            fracs=[
-                0.50,
-                0.50],
+                nmm.Material.from_library("Be12Ti"),
+            ],
+            fracs=[0.50, 0.50],
             percent_type="vo",
         )
 
@@ -119,33 +114,34 @@ class test_object_properties(unittest.TestCase):
 
         test_material = nmm.Material.from_mixture(
             materials=[
-                nmm.Material.from_library('Pb842Li158', temperature=500),
-                nmm.Material.from_library('SiC')
+                nmm.Material.from_library("Pb842Li158", temperature=500),
+                nmm.Material.from_library("SiC"),
             ],
-            fracs=[0.5, 0.5])
+            fracs=[0.5, 0.5],
+        )
 
         assert test_material.name is None
-        test_material.name = 'tag_set_after_creation'
-        assert test_material.name == 'tag_set_after_creation'
+        test_material.name = "tag_set_after_creation"
+        assert test_material.name == "tag_set_after_creation"
 
         test_material.openmc_material
-        assert test_material.openmc_material.name == 'tag_set_after_creation'
+        assert test_material.openmc_material.name == "tag_set_after_creation"
 
         test_material = nmm.Material.from_mixture(
             materials=[
-                nmm.Material.from_library('Pb842Li158', temperature=500),
-                nmm.Material.from_library('SiC')
+                nmm.Material.from_library("Pb842Li158", temperature=500),
+                nmm.Material.from_library("SiC"),
             ],
             fracs=[0.5, 0.5],
-            name='tag_set_on_creation')
+            name="tag_set_on_creation",
+        )
 
-        assert test_material.name == 'tag_set_on_creation'
+        assert test_material.name == "tag_set_on_creation"
 
         test_material.openmc_material
-        assert test_material.openmc_material.name == 'tag_set_on_creation'
+        assert test_material.openmc_material.name == "tag_set_on_creation"
 
-    def test_from_mixture_attributes_from_material_objects_and_openmc_materials(
-            self):
+    def test_from_mixture_attributes_from_material_objects_and_openmc_materials(self):
         # tests that from_mixtures made from material objects and neutronics
         # materials have the same properties
 
@@ -153,10 +149,9 @@ class test_object_properties(unittest.TestCase):
             name="test_material_1",
             materials=[
                 nmm.Material.from_library("Li4SiO4"),
-                nmm.Material.from_library("Be12Ti")],
-            fracs=[
-                0.5,
-                0.5],
+                nmm.Material.from_library("Be12Ti"),
+            ],
+            fracs=[0.5, 0.5],
             percent_type="vo",
         ).openmc_material
 
@@ -228,11 +223,11 @@ class test_object_properties(unittest.TestCase):
     def test_density_of_mixed_materials_from_density(self):
 
         test_material = nmm.Material.from_library(
-            "H2O", temperature=300, pressure=100000)
+            "H2O", temperature=300, pressure=100000
+        )
         test_mixed_material = nmm.Material.from_mixture(
-            name="test_mixed_material",
-            materials=[test_material],
-            fracs=[1])
+            name="test_mixed_material", materials=[test_material], fracs=[1]
+        )
 
         assert test_material.openmc_material.density == pytest.approx(
             test_mixed_material.openmc_material.density
@@ -269,21 +264,22 @@ class test_object_properties(unittest.TestCase):
         test_material_1 = nmm.Material.from_library("Li4SiO4").openmc_material
 
         test_material_2 = nmm.Material.from_library(
-            "Li4SiO4", packing_fraction=1).openmc_material
+            "Li4SiO4", packing_fraction=1
+        ).openmc_material
 
         assert test_material_1.density == test_material_2.density
 
         test_material_3 = nmm.Material.from_library(
-            "Li4SiO4", packing_fraction=0.5).openmc_material
+            "Li4SiO4", packing_fraction=0.5
+        ).openmc_material
 
-        assert test_material_3.density == pytest.approx(
-            test_material_1.density * 0.5)
+        assert test_material_3.density == pytest.approx(test_material_1.density * 0.5)
 
         test_material_4 = nmm.Material.from_library(
-            "Li4SiO4", packing_fraction=0.75).openmc_material
+            "Li4SiO4", packing_fraction=0.75
+        ).openmc_material
 
-        assert test_material_4.density == pytest.approx(
-            test_material_1.density * 0.75)
+        assert test_material_4.density == pytest.approx(test_material_1.density * 0.75)
 
     def test_packing_fraction_for_from_mixture_function(self):
 
@@ -291,10 +287,9 @@ class test_object_properties(unittest.TestCase):
             name="test_material_5",
             materials=[
                 nmm.Material.from_library("tungsten"),
-                nmm.Material.from_library("eurofer")],
-            fracs=[
-                0.5,
-                0.5],
+                nmm.Material.from_library("eurofer"),
+            ],
+            fracs=[0.5, 0.5],
         ).openmc_material
 
         test_material_6 = nmm.Material.from_mixture(
@@ -317,8 +312,7 @@ class test_object_properties(unittest.TestCase):
             fracs=[0.5, 0.5],
         ).openmc_material
 
-        assert test_material_7.density == pytest.approx(
-            test_material_5.density * 0.5)
+        assert test_material_7.density == pytest.approx(test_material_5.density * 0.5)
 
     def test_packing_fraction_of_a_from_mixture(self):
 
@@ -358,23 +352,36 @@ class test_object_properties(unittest.TestCase):
         )
 
         test_material_9 = openmc.Material.mix_materials(
-            name="test_material_9", materials=[
+            name="test_material_9",
+            materials=[
                 nmm.Material.from_library(
-                    "tungsten", packing_fraction=1).openmc_material, nmm.Material.from_library(
-                    "eurofer", packing_fraction=1).openmc_material, ], fracs=[
-                0.5, 0.5], percent_type="vo", )
+                    "tungsten", packing_fraction=1
+                ).openmc_material,
+                nmm.Material.from_library(
+                    "eurofer", packing_fraction=1
+                ).openmc_material,
+            ],
+            fracs=[0.5, 0.5],
+            percent_type="vo",
+        )
 
         assert test_material_8.density == test_material_9.density
 
         test_material_10 = openmc.Material.mix_materials(
-            name="test_material_10", materials=[
+            name="test_material_10",
+            materials=[
                 nmm.Material.from_library(
-                    "tungsten", packing_fraction=0.5).openmc_material, nmm.Material.from_library(
-                    "eurofer", packing_fraction=0.5).openmc_material, ], fracs=[
-                0.5, 0.5], percent_type="vo", )
+                    "tungsten", packing_fraction=0.5
+                ).openmc_material,
+                nmm.Material.from_library(
+                    "eurofer", packing_fraction=0.5
+                ).openmc_material,
+            ],
+            fracs=[0.5, 0.5],
+            percent_type="vo",
+        )
 
-        assert test_material_10.density == pytest.approx(
-            test_material_8.density * 0.5)
+        assert test_material_10.density == pytest.approx(test_material_8.density * 0.5)
 
     def test_from_mixture_vs_mix_materials(self):
 
@@ -382,10 +389,9 @@ class test_object_properties(unittest.TestCase):
             name="test_material_11",
             materials=[
                 nmm.Material.from_library("tungsten"),
-                nmm.Material.from_library("eurofer")],
-            fracs=[
-                0.5,
-                0.5],
+                nmm.Material.from_library("eurofer"),
+            ],
+            fracs=[0.5, 0.5],
         ).openmc_material
 
         test_material_12 = openmc.Material.mix_materials(
@@ -398,8 +404,7 @@ class test_object_properties(unittest.TestCase):
             percent_type="vo",
         )
 
-        assert pytest.approx(
-            test_material_11.density) == test_material_12.density
+        assert pytest.approx(test_material_11.density) == test_material_12.density
 
         test_material_13 = nmm.Material.from_mixture(
             name="test_material_13",
@@ -411,14 +416,20 @@ class test_object_properties(unittest.TestCase):
         ).openmc_material
 
         test_material_14 = openmc.Material.mix_materials(
-            name="test_material_14", materials=[
+            name="test_material_14",
+            materials=[
                 nmm.Material.from_library(
-                    "tungsten", packing_fraction=0.6).openmc_material, nmm.Material.from_library(
-                    "eurofer", packing_fraction=0.8).openmc_material, ], fracs=[
-                0.3, 0.7], percent_type="vo", )
+                    "tungsten", packing_fraction=0.6
+                ).openmc_material,
+                nmm.Material.from_library(
+                    "eurofer", packing_fraction=0.8
+                ).openmc_material,
+            ],
+            fracs=[0.3, 0.7],
+            percent_type="vo",
+        )
 
-        assert pytest.approx(
-            test_material_13.density) == test_material_14.density
+        assert pytest.approx(test_material_13.density) == test_material_14.density
 
     def test_json_dump_works(self):
         test_material = nmm.Material.from_mixture(
@@ -443,10 +454,8 @@ class test_object_properties(unittest.TestCase):
         test_material_in_json_form = test_material.to_json()
 
         assert "test_material" in list(test_material_in_json_form.keys())
-        assert "percent_type" in test_material_in_json_form["test_material"].keys(
-        )
-        assert "packing_fraction" in test_material_in_json_form["test_material"].keys(
-        )
+        assert "percent_type" in test_material_in_json_form["test_material"].keys()
+        assert "packing_fraction" in test_material_in_json_form["test_material"].keys()
 
     def test_json_dump_contains_correct_values(self):
         test_material = nmm.Material.from_mixture(
@@ -468,11 +477,13 @@ class test_object_properties(unittest.TestCase):
             """checks a ValueError is raised when the fracs are above 1"""
 
             nmm.Material.from_mixture(
-                name="test_material", materials=[
-                    nmm.Material.from_library(
-                        "tungsten", packing_fraction=0.6), nmm.Material.from_library(
-                        "eurofer", packing_fraction=0.8), ], fracs=[
-                    0.3, 0.75], )
+                name="test_material",
+                materials=[
+                    nmm.Material.from_library("tungsten", packing_fraction=0.6),
+                    nmm.Material.from_library("eurofer", packing_fraction=0.8),
+                ],
+                fracs=[0.3, 0.75],
+            )
 
         with warnings.catch_warnings(record=True) as w:
             # Cause all warnings to always be triggered.
@@ -485,17 +496,20 @@ class test_object_properties(unittest.TestCase):
             # the second entry is needed as OpenMC material mixer also raises
             # and error
             assert "warning sum of MutliMaterials.fracs do not sum to 1." in str(
-                w[-2].message)
+                w[-2].message
+            )
 
         def too_small_fracs():
             """checks a ValueError is raised when the fracs are above 1"""
 
             nmm.Material.from_mixture(
-                name="test_material", materials=[
-                    nmm.Material.from_library(
-                        "tungsten", packing_fraction=0.6), nmm.Material.from_library(
-                        "eurofer", packing_fraction=0.8), ], fracs=[
-                    0.3, 0.65], )
+                name="test_material",
+                materials=[
+                    nmm.Material.from_library("tungsten", packing_fraction=0.6),
+                    nmm.Material.from_library("eurofer", packing_fraction=0.8),
+                ],
+                fracs=[0.3, 0.65],
+            )
 
         with warnings.catch_warnings(record=True) as w:
             # Cause all warnings to always be triggered.
@@ -508,18 +522,22 @@ class test_object_properties(unittest.TestCase):
             # the second entry is needed as OpenMC material mixer also raises
             # and error
             assert "warning sum of MutliMaterials.fracs do not sum to 1." in str(
-                w[-2].message)
+                w[-2].message
+            )
 
         def test_incorrect_packing_fraction():
             """checks a ValueError is raised when the packing_fraction is the
             wrong type"""
 
             nmm.Material.from_mixture(
-                name="test_material", materials=[
-                    nmm.Material.from_library(
-                        "tungsten", packing_fraction=0.6), nmm.Material.from_library(
-                        "eurofer", packing_fraction=0.8), ], fracs=[
-                    0.3, 0.7], packing_fraction="1")
+                name="test_material",
+                materials=[
+                    nmm.Material.from_library("tungsten", packing_fraction=0.6),
+                    nmm.Material.from_library("eurofer", packing_fraction=0.8),
+                ],
+                fracs=[0.3, 0.7],
+                packing_fraction="1",
+            )
 
         self.assertRaises(ValueError, test_incorrect_packing_fraction)
 
@@ -528,11 +546,14 @@ class test_object_properties(unittest.TestCase):
             too large"""
 
             nmm.Material.from_mixture(
-                name="test_material", materials=[
-                    nmm.Material.from_library(
-                        "tungsten", packing_fraction=0.6), nmm.Material.from_library(
-                        "eurofer", packing_fraction=0.8), ], fracs=[
-                    0.3, 0.7], packing_fraction=1.1)
+                name="test_material",
+                materials=[
+                    nmm.Material.from_library("tungsten", packing_fraction=0.6),
+                    nmm.Material.from_library("eurofer", packing_fraction=0.8),
+                ],
+                fracs=[0.3, 0.7],
+                packing_fraction=1.1,
+            )
 
         self.assertRaises(ValueError, test_too_large_packing_fraction)
 
@@ -541,11 +562,14 @@ class test_object_properties(unittest.TestCase):
             too large"""
 
             nmm.Material.from_mixture(
-                name="test_material", materials=[
-                    nmm.Material.from_library(
-                        "tungsten", packing_fraction=0.6), nmm.Material.from_library(
-                        "eurofer", packing_fraction=0.8), ], fracs=[
-                    0.3, 0.7], packing_fraction=-0.1)
+                name="test_material",
+                materials=[
+                    nmm.Material.from_library("tungsten", packing_fraction=0.6),
+                    nmm.Material.from_library("eurofer", packing_fraction=0.8),
+                ],
+                fracs=[0.3, 0.7],
+                packing_fraction=-0.1,
+            )
 
         self.assertRaises(ValueError, test_too_small_packing_fraction)
 
@@ -560,7 +584,7 @@ class test_object_properties(unittest.TestCase):
                 nmm.Material.from_library("eurofer"),
             ],
             fracs=[0.3, 0.7],
-            temperature=283.15
+            temperature=283.15,
         )
 
         assert test_material.temperature == 283.15
@@ -582,7 +606,7 @@ class test_object_properties(unittest.TestCase):
                 nmm.Material.from_library("eurofer"),
             ],
             fracs=[0.3, 0.7],
-            temperature=300
+            temperature=300,
         )
 
         assert test_material.temperature == 300
